Changelog
=========

0.0.2 (2025-03-14)
------------------

- switched to underscores in project name
- added placeholder support to: `to-mel-spectrogram`, `to-mfcc-spectrogram`, `to-stft-spectrogram`


0.0.1 (2024-07-05)
------------------

- initial release

